@@ -154,8 +154,8 @@ gst_identity_getcaps (GstPad *pad, GstCaps *caps)
   return gst_pad_get_allowed_caps (otherpad);
 }
 
-static GstPadConnectReturn
-gst_identity_connect (GstPad *pad, GstCaps *caps)
+static GstPadLinkReturn
+gst_identity_link (GstPad *pad, GstCaps *caps)
 {
   GstIdentity *identity;
   GstPad *otherpad;
@@ -166,7 +166,7 @@ gst_identity_connect (GstPad *pad, GstCaps *caps)
   if (GST_CAPS_IS_FIXED (caps))
     return gst_pad_try_set_caps (otherpad, caps);
   else
-    return GST_PAD_CONNECT_DELAYED;
+    return GST_PAD_LINK_DELAYED;
 }
 
 static void 
@@ -176,12 +176,12 @@ gst_identity_init (GstIdentity *identity)
   gst_element_add_pad (GST_ELEMENT (identity), identity->sinkpad);
   gst_pad_set_chain_function (identity->sinkpad, GST_DEBUG_FUNCPTR (gst_identity_chain));
   gst_pad_set_bufferpool_function (identity->sinkpad, gst_identity_get_bufferpool);
-  gst_pad_set_connect_function (identity->sinkpad, gst_identity_connect);
+  gst_pad_set_link_function (identity->sinkpad, gst_identity_link);
   gst_pad_set_getcaps_function (identity->sinkpad, gst_identity_getcaps);
   
   identity->srcpad = gst_pad_new ("src", GST_PAD_SRC);
   gst_element_add_pad (GST_ELEMENT (identity), identity->srcpad);
-  gst_pad_set_connect_function (identity->srcpad, gst_identity_connect);
+  gst_pad_set_link_function (identity->srcpad, gst_identity_link);
   gst_pad_set_getcaps_function (identity->srcpad, gst_identity_getcaps);
 
   identity->loop_based = FALSE;
@@ -265,10 +265,18 @@ gst_identity_loop (GstElement *element)
   
   buf = gst_pad_pull (identity->sinkpad);
   if (GST_IS_EVENT (buf)) {
-    gst_pad_event_default (identity->sinkpad, GST_EVENT (buf));
-  }
+    GstEvent *event = GST_EVENT (buf);
 
-  gst_identity_chain (identity->sinkpad, buf);
+    if (GST_EVENT_IS_INTERRUPT (event)) {
+      gst_event_unref (event);
+    }
+    else {
+      gst_pad_event_default (identity->sinkpad, event);
+    }
+  }
+  else {
+    gst_identity_chain (identity->sinkpad, buf);
+  }
 }
 
 static void 
