@@ -119,17 +119,17 @@ gst_tee_class_init (GstTeeClass *klass)
   gstelement_class->request_new_pad = GST_DEBUG_FUNCPTR(gst_tee_request_new_pad);
 }
 
-static GstPadConnectReturn 
-gst_tee_sinkconnect (GstPad *pad, GstCaps *caps) 
+static GstPadLinkReturn 
+gst_tee_sinklink (GstPad *pad, GstCaps *caps) 
 {
   GstTee *tee;
   const GList *pads;
-  GstPadConnectReturn set_retval;
+  GstPadLinkReturn set_retval;
   
   tee = GST_TEE (gst_pad_get_parent (pad));
 
   if (!GST_CAPS_IS_FIXED (caps)) {
-    return GST_PAD_CONNECT_DELAYED;
+    return GST_PAD_LINK_DELAYED;
   }
 
   /* go through all the src pads */
@@ -146,7 +146,7 @@ gst_tee_sinkconnect (GstPad *pad, GstCaps *caps)
       return set_retval;
     }
   }
-  return GST_PAD_CONNECT_OK;
+  return GST_PAD_LINK_OK;
 }
 
 static void 
@@ -155,7 +155,7 @@ gst_tee_init (GstTee *tee)
   tee->sinkpad = gst_pad_new ("sink", GST_PAD_SINK);
   gst_element_add_pad (GST_ELEMENT (tee), tee->sinkpad);
   gst_pad_set_chain_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_tee_chain));
-  gst_pad_set_connect_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_tee_sinkconnect));
+  gst_pad_set_link_function (tee->sinkpad, GST_DEBUG_FUNCPTR (gst_tee_sinklink));
 
   tee->silent = FALSE;
   tee->last_message = NULL;
