@@ -110,23 +110,26 @@ gst_element_factory_find (const gchar *name)
 static void
 gst_element_details_free (GstElementDetails *dp)
 {
-  g_return_if_fail (dp);
-
-  if (dp->longname)
-    g_free (dp->longname);
-  if (dp->klass)
-    g_free (dp->klass);
-  if (dp->description)
-    g_free (dp->description);
-  if (dp->version)
-    g_free (dp->version);
-  if (dp->author)
-    g_free (dp->author);
-  if (dp->copyright)
-    g_free (dp->copyright);
+  g_free (dp->longname);
+  g_free (dp->klass);
+  g_free (dp->description);
+  g_free (dp->version);
+  g_free (dp->author);
+  g_free (dp->copyright);
   g_free (dp);
 }
 
+static void
+gst_element_factory_cleanup (GstElementFactory *factory)
+{
+  if (factory->details_dynamic) {
+    gst_element_details_free (factory->details);
+    factory->details_dynamic = FALSE;
+  }
+
+  g_free (GST_PLUGIN_FEATURE (factory)->name);
+}
+
 /**
  * gst_element_factory_new:
  * @name: name of new elementfactory
@@ -152,13 +155,12 @@ gst_element_factory_new (const gchar *name, GType type,
 
   if (!factory)
     factory = GST_ELEMENT_FACTORY (g_object_new (GST_TYPE_ELEMENT_FACTORY, NULL));
-
-  if (factory->details_dynamic) {
-    gst_element_details_free (factory->details);
-    factory->details_dynamic = FALSE;
+  else {
+    gst_element_factory_cleanup (factory);
   }
 
   factory->details = details;
+  factory->details_dynamic = FALSE;
 
   if (!factory->type)
     factory->type = type;
@@ -181,7 +183,7 @@ gst_element_factory_new (const gchar *name, GType type,
  *
  * Returns: new #GstElement
  */
-GstElement *
+GstElement*
 gst_element_factory_create (GstElementFactory *factory,
                            const gchar *name)
 {
@@ -195,7 +197,7 @@ gst_element_factory_create (GstElementFactory *factory,
 
   GST_DEBUG (GST_CAT_ELEMENT_FACTORY,
              "creating element from factory \"%s\" (name \"%s\", type %d)", 
-             GST_OBJECT_NAME (factory), name, (gint) factory->type);
+             GST_PLUGIN_FEATURE_NAME (factory), name, (gint) factory->type);
 
   if (factory->type == 0) {
       g_critical ("Factory for `%s' has no type",
@@ -210,7 +212,7 @@ gst_element_factory_create (GstElementFactory *factory,
   /* attempt to set the elemenfactory class pointer if necessary */
   oclass = GST_ELEMENT_CLASS (G_OBJECT_GET_CLASS (element));
   if (oclass->elementfactory == NULL) {
-    GST_DEBUG (GST_CAT_ELEMENT_FACTORY, "class %s", GST_OBJECT_NAME (factory));
+    GST_DEBUG (GST_CAT_ELEMENT_FACTORY, "class %s", GST_PLUGIN_FEATURE_NAME (factory));
     oclass->elementfactory = factory;
 
     /* copy pad template pointers to the element class, 
@@ -280,7 +282,9 @@ gst_element_factory_make (const gchar *factoryname, const gchar *name)
 GstElement*
 gst_element_factory_make_or_warn (const gchar *factoryname, const gchar *name)
 {
-  GstElement *element = gst_element_factory_make (factoryname, name);
+  GstElement *element;
+  
+  element = gst_element_factory_make (factoryname, name);
 
   if (element == NULL) 
     g_warning ("Could not create element from factory %s !\n", factoryname);
@@ -301,8 +305,8 @@ gst_element_factory_add_pad_template (GstElementFactory *factory,
 {
   GList *padtemplates;
   
-  g_return_if_fail(factory != NULL);
-  g_return_if_fail(templ != NULL);
+  g_return_if_fail (factory != NULL);
+  g_return_if_fail (templ != NULL);
 
   padtemplates = factory->padtemplates;
 
@@ -401,7 +405,7 @@ gst_element_factory_can_sink_caps (GstElementFactory *factory,
 void
 gst_element_factory_set_rank (GstElementFactory *factory, guint16 rank)
 {
-  g_return_if_fail(factory != NULL);
+  g_return_if_fail (factory != NULL);
   factory->rank = rank;
 }
 
