@@ -134,72 +134,6 @@ gst_buffer_flag_get_type (void)
 }
 
 
-/* enumerations from "gstcache.h" */
-GType
-gst_cache_certainty_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_CACHE_UNKNOWN, "GST_CACHE_UNKNOWN", "unknown" },
-      { GST_CACHE_CERTAIN, "GST_CACHE_CERTAIN", "certain" },
-      { GST_CACHE_FUZZY, "GST_CACHE_FUZZY", "fuzzy" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstCacheCertainty", values);
-  }
-  return etype;
-}
-
-GType
-gst_cache_entry_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_CACHE_ENTRY_ID, "GST_CACHE_ENTRY_ID", "id" },
-      { GST_CACHE_ENTRY_ASSOCIATION, "GST_CACHE_ENTRY_ASSOCIATION", "association" },
-      { GST_CACHE_ENTRY_OBJECT, "GST_CACHE_ENTRY_OBJECT", "object" },
-      { GST_CACHE_ENTRY_FORMAT, "GST_CACHE_ENTRY_FORMAT", "format" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstCacheEntryType", values);
-  }
-  return etype;
-}
-
-GType
-gst_cache_lookup_method_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GST_CACHE_LOOKUP_EXACT, "GST_CACHE_LOOKUP_EXACT", "exact" },
-      { GST_CACHE_LOOKUP_BEFORE, "GST_CACHE_LOOKUP_BEFORE", "before" },
-      { GST_CACHE_LOOKUP_AFTER, "GST_CACHE_LOOKUP_AFTER", "after" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GstCacheLookupMethod", values);
-  }
-  return etype;
-}
-
-GType
-gst_assoc_flags_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GFlagsValue values[] = {
-      { GST_ACCOCIATION_FLAG_NONE, "GST_ACCOCIATION_FLAG_NONE", "none" },
-      { GST_ACCOCIATION_FLAG_KEY_UNIT, "GST_ACCOCIATION_FLAG_KEY_UNIT", "key-unit" },
-      { 0, NULL, NULL }
-    };
-    etype = g_flags_register_static ("GstAssocFlags", values);
-  }
-  return etype;
-}
-
-
 /* enumerations from "gstclock.h" */
 GType
 gst_clock_entry_status_get_type (void)
@@ -352,6 +286,7 @@ gst_event_type_get_type (void)
       { GST_EVENT_RATE, "GST_EVENT_RATE", "rate" },
       { GST_EVENT_FILLER, "GST_EVENT_FILLER", "filler" },
       { GST_EVENT_TS_OFFSET, "GST_EVENT_TS_OFFSET", "ts-offset" },
+      { GST_EVENT_INTERRUPT, "GST_EVENT_INTERRUPT", "interrupt" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GstEventType", values);
@@ -432,41 +367,119 @@ gst_format_get_type (void)
 }
 
 
-/* enumerations from "gstpad.h" */
+/* enumerations from "gstindex.h" */
 GType
-gst_pad_connect_return_get_type (void)
+gst_index_certainty_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { GST_PAD_CONNECT_REFUSED, "GST_PAD_CONNECT_REFUSED", "refused" },
-      { GST_PAD_CONNECT_DELAYED, "GST_PAD_CONNECT_DELAYED", "delayed" },
-      { GST_PAD_CONNECT_OK, "GST_PAD_CONNECT_OK", "ok" },
-      { GST_PAD_CONNECT_DONE, "GST_PAD_CONNECT_DONE", "done" },
+      { GST_INDEX_UNKNOWN, "GST_INDEX_UNKNOWN", "unknown" },
+      { GST_INDEX_CERTAIN, "GST_INDEX_CERTAIN", "certain" },
+      { GST_INDEX_FUZZY, "GST_INDEX_FUZZY", "fuzzy" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("GstPadConnectReturn", values);
+    etype = g_enum_register_static ("GstIndexCertainty", values);
   }
   return etype;
 }
 
 GType
-gst_pad_query_type_get_type (void)
+gst_index_entry_type_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { GST_PAD_QUERY_NONE, "GST_PAD_QUERY_NONE", "none" },
-      { GST_PAD_QUERY_TOTAL, "GST_PAD_QUERY_TOTAL", "total" },
-      { GST_PAD_QUERY_POSITION, "GST_PAD_QUERY_POSITION", "position" },
-      { GST_PAD_QUERY_LATENCY, "GST_PAD_QUERY_LATENCY", "latency" },
-      { GST_PAD_QUERY_JITTER, "GST_PAD_QUERY_JITTER", "jitter" },
-      { GST_PAD_QUERY_START, "GST_PAD_QUERY_START", "start" },
-      { GST_PAD_QUERY_SEGMENT_END, "GST_PAD_QUERY_SEGMENT_END", "segment-end" },
-      { GST_PAD_QUERY_RATE, "GST_PAD_QUERY_RATE", "rate" },
+      { GST_INDEX_ENTRY_ID, "GST_INDEX_ENTRY_ID", "id" },
+      { GST_INDEX_ENTRY_ASSOCIATION, "GST_INDEX_ENTRY_ASSOCIATION", "association" },
+      { GST_INDEX_ENTRY_OBJECT, "GST_INDEX_ENTRY_OBJECT", "object" },
+      { GST_INDEX_ENTRY_FORMAT, "GST_INDEX_ENTRY_FORMAT", "format" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("GstPadQueryType", values);
+    etype = g_enum_register_static ("GstIndexEntryType", values);
+  }
+  return etype;
+}
+
+GType
+gst_index_lookup_method_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_INDEX_LOOKUP_EXACT, "GST_INDEX_LOOKUP_EXACT", "exact" },
+      { GST_INDEX_LOOKUP_BEFORE, "GST_INDEX_LOOKUP_BEFORE", "before" },
+      { GST_INDEX_LOOKUP_AFTER, "GST_INDEX_LOOKUP_AFTER", "after" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstIndexLookupMethod", values);
+  }
+  return etype;
+}
+
+GType
+gst_assoc_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { GST_ASSOCIATION_FLAG_NONE, "GST_ASSOCIATION_FLAG_NONE", "none" },
+      { GST_ASSOCIATION_FLAG_KEY_UNIT, "GST_ASSOCIATION_FLAG_KEY_UNIT", "key-unit" },
+      { GST_ASSOCIATION_FLAG_LAST, "GST_ASSOCIATION_FLAG_LAST", "last" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("GstAssocFlags", values);
+  }
+  return etype;
+}
+
+GType
+gst_index_resolver_method_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_INDEX_RESOLVER_CUSTOM, "GST_INDEX_RESOLVER_CUSTOM", "custom" },
+      { GST_INDEX_RESOLVER_GTYPE, "GST_INDEX_RESOLVER_GTYPE", "gtype" },
+      { GST_INDEX_RESOLVER_PATH, "GST_INDEX_RESOLVER_PATH", "path" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstIndexResolverMethod", values);
+  }
+  return etype;
+}
+
+GType
+gst_index_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_INDEX_WRITABLE, "GST_INDEX_WRITABLE", "writable" },
+      { GST_INDEX_READABLE, "GST_INDEX_READABLE", "readable" },
+      { GST_INDEX_FLAG_LAST, "GST_INDEX_FLAG_LAST", "flag-last" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstIndexFlags", values);
+  }
+  return etype;
+}
+
+
+/* enumerations from "gstpad.h" */
+GType
+gst_pad_link_return_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_PAD_LINK_REFUSED, "GST_PAD_LINK_REFUSED", "refused" },
+      { GST_PAD_LINK_DELAYED, "GST_PAD_LINK_DELAYED", "delayed" },
+      { GST_PAD_LINK_OK, "GST_PAD_LINK_OK", "ok" },
+      { GST_PAD_LINK_DONE, "GST_PAD_LINK_DONE", "done" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstPadLinkReturn", values);
   }
   return etype;
 }
@@ -494,7 +507,7 @@ gst_pad_flags_get_type (void)
   if (etype == 0) {
     static const GEnumValue values[] = {
       { GST_PAD_DISABLED, "GST_PAD_DISABLED", "disabled" },
-      { GST_PAD_EOS, "GST_PAD_EOS", "eos" },
+      { GST_PAD_NEGOTIATING, "GST_PAD_NEGOTIATING", "negotiating" },
       { GST_PAD_FLAG_LAST, "GST_PAD_FLAG_LAST", "flag-last" },
       { 0, NULL, NULL }
     };
@@ -565,6 +578,29 @@ gst_props_type_get_type (void)
 }
 
 
+/* enumerations from "gstquery.h" */
+GType
+gst_query_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_QUERY_NONE, "GST_QUERY_NONE", "none" },
+      { GST_QUERY_TOTAL, "GST_QUERY_TOTAL", "total" },
+      { GST_QUERY_POSITION, "GST_QUERY_POSITION", "position" },
+      { GST_QUERY_LATENCY, "GST_QUERY_LATENCY", "latency" },
+      { GST_QUERY_JITTER, "GST_QUERY_JITTER", "jitter" },
+      { GST_QUERY_START, "GST_QUERY_START", "start" },
+      { GST_QUERY_SEGMENT_END, "GST_QUERY_SEGMENT_END", "segment-end" },
+      { GST_QUERY_RATE, "GST_QUERY_RATE", "rate" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstQueryType", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gstscheduler.h" */
 GType
 gst_scheduler_flags_get_type (void)
@@ -666,7 +702,7 @@ gst_parse_error_get_type (void)
       { GST_PARSE_ERROR_SYNTAX, "GST_PARSE_ERROR_SYNTAX", "syntax" },
       { GST_PARSE_ERROR_NO_SUCH_ELEMENT, "GST_PARSE_ERROR_NO_SUCH_ELEMENT", "no-such-element" },
       { GST_PARSE_ERROR_NO_SUCH_PROPERTY, "GST_PARSE_ERROR_NO_SUCH_PROPERTY", "no-such-property" },
-      { GST_PARSE_ERROR_CONNECT, "GST_PARSE_ERROR_CONNECT", "connect" },
+      { GST_PARSE_ERROR_LINK, "GST_PARSE_ERROR_LINK", "link" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GstParseError", values);
