@@ -173,8 +173,8 @@ gst_queue_class_init (GstQueueClass *klass)
   gstelement_class->release_locks = GST_DEBUG_FUNCPTR(gst_queue_release_locks);
 }
 
-static GstPadConnectReturn
-gst_queue_connect (GstPad *pad, GstCaps *caps)
+static GstPadLinkReturn
+gst_queue_link (GstPad *pad, GstCaps *caps)
 {
   GstQueue *queue = GST_QUEUE (gst_pad_get_parent (pad));
   GstPad *otherpad;
@@ -184,7 +184,7 @@ gst_queue_connect (GstPad *pad, GstCaps *caps)
   else
     otherpad = queue->srcpad;
 
-  return gst_pad_proxy_connect (otherpad, caps);
+  return gst_pad_proxy_link (otherpad, caps);
 }
 
 static GstCaps*
@@ -212,13 +212,13 @@ gst_queue_init (GstQueue *queue)
   gst_pad_set_chain_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_chain));
   gst_element_add_pad (GST_ELEMENT (queue), queue->sinkpad);
   gst_pad_set_bufferpool_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_get_bufferpool));
-  gst_pad_set_connect_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_connect));
+  gst_pad_set_link_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_link));
   gst_pad_set_getcaps_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_getcaps));
 
   queue->srcpad = gst_pad_new ("src", GST_PAD_SRC);
   gst_pad_set_get_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_get));
   gst_element_add_pad (GST_ELEMENT (queue), queue->srcpad);
-  gst_pad_set_connect_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_connect));
+  gst_pad_set_link_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_link));
   gst_pad_set_getcaps_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_getcaps));
   gst_pad_set_event_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_handle_src_event));
 
@@ -485,7 +485,7 @@ restart:
       GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "interrupted!!");
       g_mutex_unlock (queue->qlock);
       if (gst_scheduler_interrupt (gst_pad_get_scheduler (queue->srcpad), GST_ELEMENT (queue)))
-        return NULL;
+        return GST_BUFFER (gst_event_new (GST_EVENT_INTERRUPT));
       goto restart;
     }
     if (GST_STATE (queue) != GST_STATE_PLAYING) {
@@ -571,6 +571,8 @@ gst_queue_handle_src_event (GstPad *pad, GstEvent *event)
 {
   GstQueue *queue;
   gboolean res;
+  gint event_type;
+  gint flag_flush = 0;
 
   queue = GST_QUEUE (GST_OBJECT_PARENT (pad));
 
@@ -579,30 +581,37 @@ gst_queue_handle_src_event (GstPad *pad, GstEvent *event)
   if (gst_element_get_state (GST_ELEMENT (queue)) == GST_STATE_PLAYING) {
     /* push the event to the queue for upstream consumption */
     g_async_queue_push(queue->events, event);
-    g_mutex_unlock (queue->qlock);
     g_warning ("FIXME: sending event in a running queue");
     /* FIXME wait for delivery of the event here, then return the result
      * instead of FALSE */
-    return FALSE;
+    res = FALSE;
+    goto done;
   }
 
+  event_type = GST_EVENT_TYPE (event);
+  if (event_type == GST_EVENT_SEEK)
+    flag_flush = GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH;
+
   res = gst_pad_event_default (pad, event); 
-  switch (GST_EVENT_TYPE (event)) {
+
+  switch (event_type) {
     case GST_EVENT_FLUSH:
       GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "FLUSH event, flushing queue\n");
       gst_queue_locked_flush (queue);
       break;
     case GST_EVENT_SEEK:
-      if (GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH) {
+      if (flag_flush) {
         gst_queue_locked_flush (queue);
       }
     default:
       break;
   }
+
+done:
   g_mutex_unlock (queue->qlock);
 
   /* we have to claim success, but we don't really know */
-  return TRUE;
+  return res;
 }
 
 static gboolean
@@ -626,8 +635,6 @@ gst_queue_change_state (GstElement *element)
 {
   GstQueue *queue;
   GstElementStateReturn ret;
-  GstElementState new_state;
-  g_return_val_if_fail (GST_IS_QUEUE (element), GST_STATE_FAILURE);
 
   queue = GST_QUEUE (element);
 
@@ -638,25 +645,53 @@ gst_queue_change_state (GstElement *element)
    */
   g_mutex_lock (queue->qlock);
 
-  new_state = GST_STATE_PENDING (element);
+  switch (GST_STATE_TRANSITION (element)) {
+    case GST_STATE_NULL_TO_READY:
+      gst_queue_locked_flush (queue);
+      break;
+    case GST_STATE_READY_TO_PAUSED:
+      break;
+    case GST_STATE_PAUSED_TO_PLAYING:
+      if (!GST_PAD_IS_LINKED (queue->sinkpad)) {
+        GST_DEBUG_ELEMENT (GST_CAT_STATES, queue, "queue %s is not linked", GST_ELEMENT_NAME (queue));
+        /* FIXME can this be? */
+        if (queue->reader)
+          g_cond_signal (queue->not_empty);
 
-  if (new_state == GST_STATE_READY) {
-    gst_queue_locked_flush (queue);
-  }
-  else if (new_state == GST_STATE_PLAYING) {
-    if (!GST_PAD_IS_CONNECTED (queue->sinkpad)) {
-      GST_DEBUG_ELEMENT (GST_CAT_STATES, queue, "queue %s is not connected", GST_ELEMENT_NAME (queue));
-      /* FIXME can this be? */
-      if (queue->reader)
-        g_cond_signal (queue->not_empty);
-      g_mutex_unlock (queue->qlock);
+        ret = GST_STATE_FAILURE;
+        goto error;
+      }
+      else {
+        GstScheduler *src_sched, *sink_sched;
+	    
+        src_sched = gst_pad_get_scheduler (GST_PAD_CAST (queue->srcpad));
+        sink_sched = gst_pad_get_scheduler (GST_PAD_CAST (queue->sinkpad));
 
-      return GST_STATE_FAILURE;
-    }
-    queue->interrupt = FALSE;
+        if (src_sched == sink_sched) {
+          GST_DEBUG_ELEMENT (GST_CAT_STATES, queue, "queue %s does not connect different schedulers", 
+			GST_ELEMENT_NAME (queue));
+
+	  g_warning ("queue %s does connect different schedulers",
+			GST_ELEMENT_NAME (queue));
+
+	  ret = GST_STATE_FAILURE;
+	  goto error;
+        }
+      }
+      queue->interrupt = FALSE;
+      break;
+    case GST_STATE_PLAYING_TO_PAUSED:
+      break;
+    case GST_STATE_PAUSED_TO_READY:
+      gst_queue_locked_flush (queue);
+      break;
+    case GST_STATE_READY_TO_NULL:
+      break;
   }
 
   ret = GST_ELEMENT_CLASS (parent_class)->change_state (element);
+
+error:
   g_mutex_unlock (queue->qlock);
 
   GST_DEBUG_LEAVE("('%s')", GST_ELEMENT_NAME (element));
